@@ -1,49 +1,20 @@
-from enum import Enum
+import re
 from typing import (
     Any,
-    Dict,
-    Tuple,
-    Callable,
-    TypeVar,
     cast,
-    Optional,
+    Callable,
+    Dict,
     List,
+    Optional,
+    Tuple,
+    TypeVar,
 )
-import re
 
 from robot.libraries.BuiltIn import BuiltIn  # type: ignore
 
+from .utils.data_types import AssertionOperator
 from .utils.robot_booleans import is_truthy
 
-AssertionOperator = Enum(
-    "AssertionOperator",
-    {
-        "equal": "==",
-        "==": "==",
-        "shouldbe": "==",
-        "inequal": "!=",
-        "!=": "!=",
-        "shouldnotbe": "!=",
-        "lessthan": "<",
-        "<": "<",
-        "greaterthan": ">",
-        ">": ">",
-        "<=": "<=",
-        ">=": ">=",
-        "contains": "*=",
-        "*=": "*=",
-        "starts": "^=",
-        "^=": "^=",
-        "shouldstartwith": "^=",
-        "ends": "$=",
-        "$=": "$=",
-        "matches": "$",
-        "validate": "validate",
-        "then": "then",
-        "evaluate": "then",
-    },
-)
-
 NumericalOperators = [
     AssertionOperator["=="],
     AssertionOperator["!="],
@@ -83,7 +54,6 @@ handlers: Dict[AssertionOperator, Tuple[Callable, str]] = {
     ),
 }
 
-
 T = TypeVar("T")
 
 
