@@ -2,7 +2,9 @@ from .browser_control import Control
 from .evaluation import Evaluation
 from .playwright_state import PlaywrightState
 from .getters import Getters
-from .input import Input
+from .interaction import Interaction
+from .network import Network
+from .promises import Promises
 from .waiter import Waiter
 from .webapp_state import WebAppState
 
@@ -10,8 +12,10 @@ __all__ = [
     "Control",
     "Getters",
     "Evaluation",
-    "Input",
+    "Interaction",
+    "Network",
     "PlaywrightState",
+    "Promises",
     "Waiter",
     "WebAppState",
 ]
