@@ -1,12 +1,16 @@
 import json
-from typing import Optional, Any
+from typing import (
+    Any,
+    Optional,
+)
 
 from robotlibcore import keyword  # type: ignore
 
-from ..assertion_engine import AssertionOperator, verify_assertion
+from ..assertion_engine import verify_assertion
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
 from ..utils import logger
+from ..utils.data_types import AssertionOperator
 
 
 class WebAppState(LibraryComponent):
@@ -21,7 +25,7 @@ class WebAppState(LibraryComponent):
         Get saved data from from localStorage
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ExecuteJavascriptOnPage(
+            response = stub.ExecuteJavascript(
                 Request().JavascriptCode(script=f'window.localStorage.getItem("{key}")')
             )
             logger.info(response.log)
@@ -38,7 +42,7 @@ class WebAppState(LibraryComponent):
         Save data to localStorage
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ExecuteJavascriptOnPage(
+            response = stub.ExecuteJavascript(
                 Request().JavascriptCode(
                     script=f'window.localStorage.setItem("{key}", "{value}")'
                 )
@@ -51,7 +55,7 @@ class WebAppState(LibraryComponent):
         Remove saved data with key from localStorage
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ExecuteJavascriptOnPage(
+            response = stub.ExecuteJavascript(
                 Request().JavascriptCode(
                     script=f'window.localStorage.removeItem("{key}")'
                 )
@@ -64,7 +68,7 @@ class WebAppState(LibraryComponent):
         Remove all saved data from localStorage
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ExecuteJavascriptOnPage(
+            response = stub.ExecuteJavascript(
                 Request().JavascriptCode(script="window.localStorage.clear()")
             )
             logger.info(response.log)
@@ -82,7 +86,7 @@ class WebAppState(LibraryComponent):
         Get saved data from from sessionStorage
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ExecuteJavascriptOnPage(
+            response = stub.ExecuteJavascript(
                 Request().JavascriptCode(
                     script=f'window.sessionStorage.getItem("{key}")'
                 )
@@ -101,7 +105,7 @@ class WebAppState(LibraryComponent):
         Save data to sessionStorage
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ExecuteJavascriptOnPage(
+            response = stub.ExecuteJavascript(
                 Request().JavascriptCode(
                     script=f'window.sessionStorage.setItem("{key}", "{value}")'
                 )
@@ -114,7 +118,7 @@ class WebAppState(LibraryComponent):
         Remove saved data with key from sessionStorage
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ExecuteJavascriptOnPage(
+            response = stub.ExecuteJavascript(
                 Request().JavascriptCode(
                     script=f'window.sessionStorage.removeItem("{key}")'
                 )
@@ -127,7 +131,7 @@ class WebAppState(LibraryComponent):
         Remove all saved data from sessionStorage
         """
         with self.playwright.grpc_channel() as stub:
-            response = stub.ExecuteJavascriptOnPage(
+            response = stub.ExecuteJavascript(
                 Request().JavascriptCode(script="window.sessionStorage.clear()")
             )
             logger.info(response.log)
