@@ -1,3 +1,5 @@
+from typing import Any
+
 from robot.api import logger  # type: ignore
 from robot.libraries.BuiltIn import EXECUTION_CONTEXTS  # type: ignore
 
@@ -7,13 +9,13 @@ if not EXECUTION_CONTEXTS.current:
     setattr(logger, "warn", lambda msg, html: print(f"WARN: {msg}"))
 
 
-def info(msg: str, html=False):
+def info(msg: Any, html=False):
     logger.info(msg, html)
 
 
-def debug(msg: str, html=False):
+def debug(msg: Any, html=False):
     logger.debug(msg, html)
 
 
-def warn(msg: str, html=False):
+def warn(msg: Any, html=False):
     logger.warn(msg, html)
